@@ -144,23 +144,26 @@ print_bytes_string (GString *str,
     {
       bytes = (bytes * 10) / (1 << 30);
 
-      g_string_append_printf (str, " (%lld.%lld GiB)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%"G_GUINT64_FORMAT".%"G_GUINT64_FORMAT" GiB)",
+                              bytes / 10, bytes % 10);
     }
   else if (bytes > 1 << 20)
     {
       bytes = (bytes * 10) / (1 << 20);
 
-      g_string_append_printf (str, " (%lld.%lld MiB)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%"G_GUINT64_FORMAT".%"G_GUINT64_FORMAT" MiB)",
+                              bytes / 10, bytes % 10);
     }
   else if (bytes > 1 << 10)
     {
       bytes = (bytes * 10) / (1 << 10);
 
-      g_string_append_printf (str, " (%lld.%lld KiB)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%"G_GUINT64_FORMAT".%"G_GUINT64_FORMAT" KiB)",
+                              bytes / 10, bytes % 10);
     }
   else if (bytes > 0)
     {
-      g_string_append_printf (str, " (%lld B)", bytes);
+      g_string_append_printf (str, " (%"G_GUINT64_FORMAT" B)", bytes);
     }
 }
 
